@@ -64,7 +64,7 @@ if(model$results$npar!=npar)
 {
    if(npar<=dim(model$results$beta)[1])
    {
-      cat("\nNumber of parameters adjusted from ",model$results$npar," to ", npar,"\n") 
+      message("\nNumber of parameters adjusted from ",model$results$npar," to ", npar,"\n") 
       if(is.null(model$results$AICc.unadjusted))
       {
          model$results$AICc.unadjusted=model$results$AICc
@@ -76,13 +76,13 @@ if(model$results$npar!=npar)
       model$results$npar=npar
       AICc=model$results$lnl+ 2*npar +2*npar*(npar+1)/(model$results$n - npar -1)
       model$results$AICc=AICc
-      cat("Adjusted AICc = ",AICc,"\nUnadjusted AICc = ", AICc.unadjusted,"\n") 
+      message("Adjusted AICc = ",AICc,"\nUnadjusted AICc = ", AICc.unadjusted,"\n") 
   }
   else
   {
-     cat("Specified number of parameters > number of beta parameters. No adjustment made.\n")
+     message("Specified number of parameters > number of beta parameters. No adjustment made.\n")
   }
 }
 else
-  cat("Specified number of parameters matches current value. No adjustment made.\n")
+  message("Specified number of parameters matches current value. No adjustment made.\n")
 return(model)}
