@@ -215,7 +215,7 @@ if(is.null(data$data))
 {
    if(!is.null(ddl))
    {
-      cat("Warning: specification of ddl ignored, as data have not been processed\n")
+      message("Warning: specification of ddl ignored, as data have not been processed\n")
       ddl=NULL
    }
    data.proc=process.data(data,begin.time=begin.time, model=model,mixtures=mixtures, 
@@ -232,16 +232,14 @@ if(is.null(ddl)) ddl=make.design.data(data.proc,design.parameters,right=right)
 #
 #  check to make sure all entered as lists
 #
-tryCatch(length(model.parameters), error = function(e) cat("Make sure you have a tilde at the beginning of each formula\n"))
+tryCatch(length(model.parameters), error = function(e) message("Make sure you have a tilde at the beginning of each formula\n"))
 if(length(model.parameters)!=0)
 	for(i in 1:length(model.parameters))
 	{
 		if(!is.list(model.parameters[[i]]))
-		{
-			cat("\nEach parameter distribution must be specified as a list\n")
-			stop()
-		}
-		if(is.language(model.parameters[[i]][[1]])&(is.null(names(model.parameters[[i]])) || names(model.parameters[[i]])[1]==""))cat("Make sure you have an = between formula and tilde for formula\n")
+			stop("\nEach parameter distribution must be specified as a list\n")
+		if(is.language(model.parameters[[i]][[1]])&(is.null(names(model.parameters[[i]])) || names(model.parameters[[i]])[1]==""))
+			message("Make sure you have an = between formula and tilde for formula\n")
 	}
 #
 # Run model as many as times requested if needed
@@ -255,11 +253,16 @@ while(i<=retry & !converge)
 #
    if(is.list(model.parameters))
    {
-      model<-make.mark.model(data.proc,title=title,parameters=model.parameters,
+      model<-try(make.mark.model(data.proc,title=title,parameters=model.parameters,
              ddl=ddl,initial=initial,call=match.call(),default.fixed=default.fixed,
              model.name=model.name,options=options,profile.int=profile.int,chat=chat,
-			 input.links=input.links,parm.specific=parm.specific,mlogit0=mlogit0,hessian=hessian,accumulate=accumulate)
-      model$model.parameters=model.parameters
+			 input.links=input.links,parm.specific=parm.specific,mlogit0=mlogit0,hessian=hessian,accumulate=accumulate))
+      if(class(model)[1]=="try-error")
+	  {
+		  stop("Misspecification of model or internal error in code")
+	  }
+	  else
+         model$model.parameters=model.parameters
 	  if(!run)return(model)
    }
    else
@@ -275,11 +278,11 @@ while(i<=retry & !converge)
 #
 # Run model
 #
-   runmodel<-try(run.mark.model(model,invisible=invisible,adjust=adjust,filename=filename,prefix=prefix,realvcv=realvcv,delete=delete,threads=threads,ignore.stderr=silent),silent=silent)
-   if(class(runmodel)[1]=="try-error")
+   runmodel<-run.mark.model(model,invisible=invisible,adjust=adjust,filename=filename,prefix=prefix,realvcv=realvcv,delete=delete,threads=threads,ignore.stderr=silent)
+   if(is.null(runmodel))
    {
      cat("\n\n********Following model failed to run :",model$model.name,"**********\n\n")
-     return(model)
+     return(invisible())
    }
    else
    {
@@ -289,7 +292,7 @@ while(i<=retry & !converge)
 #
       if(retry>0 && !is.null(runmodel$results$singular))
       {
-         cat("\nRe-running analysis with new starting values\n")
+         message("\nRe-running analysis with new starting values\n")
          i=i+1
          converge=FALSE
          initial=runmodel$results$beta$estimate
