@@ -11,7 +11,7 @@
 #' @return model.list: a list of \code{mark} models and optionally a table of
 #' model results.
 #' @author Jeff Laake
-#' @export
+#' @export merge.mark
 #' @seealso
 #' \code{\link{collect.models}},\code{\link{remove.mark}},\code{\link{run.models}},\code{\link{model.table}},\code{\link{dipper}}
 #' @keywords utility
@@ -60,7 +60,7 @@ merge.mark=function(...,table=TRUE)
 #       an error message and skip over it.
 #
         else
-           cat(paste("Objects must be of class mark or marklist.",names(args)[i],"ignored"))
+           message(paste("Objects must be of class mark or marklist.",names(args)[i],"ignored"))
   }
 #
 # Add a model table for the mark models if requested; assign class of marklist and
